<?php
/*********************************************************************************
 ** The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
 *
  ********************************************************************************/
$app_strings = array (
	'Groups'=>'Groups',
	'DocumentFolders'=>'Document Folders',
	'Currency'=>'Currency',
	'SINGLE_Groups'=>'Group',
	'SINGLE_DocumentFolders'=>'Document Folder',
	'SINGLE_Currency'=>'Currency',
);

$webservice_strings = array(
	'LBL_INVALID_OLD_PASSWORD' => 'Invalid value given for old password.',
	'LBL_NEW_PASSWORD_MISMATCH' => "New Password and confirm password don't match",
	'LBL_DATABASE_QUERY_ERROR' => 'Database error while performing requested operation',
	'LBL_CHANGE_PASSWORD_FAILURE' => 'Failed to change password',
);

?>